@@ -471,7 +471,7 @@ static uint16_t GetData(const uint8_t *in_buf, size_t data_size, uint8_t *out_bu
 	   	{
 		   all->BCDRamParams.GETC.Joy = rand_range(4500, 5000);
 		   all->BCDRamParams.GETC.Pot = rand_range(6000, 8000);
-		   all->BCDRamParams.GETC.DutyCycle = 200;
+		   all->BCDRamParams.GETC.AveragedPowerRatio = 50;
 
 		   WRITE_STRUCTURE(all->BCDRamParams.GETC);
 		   break;
