@@ -1,4 +1,4 @@
-def set_profile_8MRL80_6_LEn2_050(lib, id):
+def set_profile_8MRL80_6_LEn2_100(lib, id):
     worst_result = Result.Ok
     result = Result.Ok
 
@@ -18,7 +18,7 @@ def set_profile_8MRL80_6_LEn2_050(lib, id):
         FEEDBACK_ENC_REVERSE = 1
         FEEDBACK_ENC_TYPE_AUTO = 0
     feedback_settings.FeedbackFlags = FeedbackFlags_.FEEDBACK_ENC_TYPE_DIFFERENTIAL | FeedbackFlags_.FEEDBACK_ENC_TYPE_AUTO
-    feedback_settings.CountsPerTurn = 2880000
+    feedback_settings.CountsPerTurn = 1440000
     result = lib.set_feedback_settings(id, byref(feedback_settings))
 
     if result != Result.Ok:
@@ -87,7 +87,7 @@ def set_profile_8MRL80_6_LEn2_050(lib, id):
         ENGINE_CURRENT_AS_RMS = 2
         ENGINE_REVERSE = 1
     engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON
-    engine_settings.Antiplay = -7680
+    engine_settings.Antiplay = 28928
     class MicrostepMode_:
         MICROSTEP_MODE_FRAC_256 = 9
         MICROSTEP_MODE_FRAC_128 = 8
@@ -182,9 +182,9 @@ def set_profile_8MRL80_6_LEn2_050(lib, id):
         ENDER_SW1_ACTIVE_LOW = 2
         ENDER_SWAP = 1
     edges_settings.EnderFlags = EnderFlags_.ENDER_SW2_ACTIVE_LOW | EnderFlags_.ENDER_SW1_ACTIVE_LOW
-    edges_settings.LeftBorder = 72000
+    edges_settings.LeftBorder = 36000
     edges_settings.uLeftBorder = 0
-    edges_settings.RightBorder = 2808000
+    edges_settings.RightBorder = 1404000
     edges_settings.uRightBorder = 0
     result = lib.set_edges_settings(id, byref(edges_settings))
 
